/** Data to initialize a header map. */
export declare type HeadersInit = Record<string, string> | [string, string][] | Headers;
/**
 * Represents a modifiable map of HTTP headers.
 *
 * @see https://fetch.spec.whatwg.org/#headers-class
 */
export declare class Headers {
    #private;
    /**
     * Constructs a new header map.
     *
     * Optionally initialization data can be passed in.
     *
     * @param init Optional header initialization data, will be cloned.
     */
    constructor(init?: HeadersInit);
    /**
     * Returns how many headers there are.
     */
    get length(): number;
    /**
     * Appends a header to the map. If there already is a header with the given name,
     * the value will be appended.
     *
     * @param name The name of the header to append.
     * @param value The header value.
     */
    append(name: string, value: string): void;
    /**
     * Deletes all headers with the given name from the map.
     *
     * @param name The name of the headers to delete.
     */
    delete(name: string): void;
    /**
     * Returns an iterator over all the headers that have been inserted.
     */
    entries(): IterableIterator<[string, string]>;
    /**
     * Returns an iterator over all the headers that have been inserted.
     */
    [Symbol.iterator](): IterableIterator<[string, string]>;
    /**
     * Extends this header map with the values from the other.
     *
     * Modifies the header map in-place.
     *
     * @param other the header entries to import into this map.
     * @hidden
     * @see https://fetch.spec.whatwg.org/#concept-headers-fill
     */
    fill(other: HeadersInit): void;
    /** Determines whether there is a header with the given name in the map. */
    has(name: string): boolean;
    /**
     * Gets the header with the given name, or returns `undefined` if it's not there.
     *
     * If there are multiple header values they will be joined together.
     */
    get(name: string): string | undefined;
    /** Returns an iterator over all the header names in the map. */
    keys(): IterableIterator<string>;
    /**
     * Sets the given header name to the given value.
     *
     * If there were any headers with the same name in the map before, they are overwritten.
     *
     * @param name The name of the header to insert.
     * @param value The value of the header to insert.
     */
    set(name: string, value: string): void;
    /**
     * Converts the header map into a record.
     *
     * @returns The record.
     */
    toRecord(): Record<string, string[]>;
    /** Returns an iterator over all the header values in the map. */
    values(): IterableIterator<string>;
}
